summaryrefslogtreecommitdiff
path: root/lib/param
diff options
context:
space:
mode:
authorAndreas Schneider <asn@samba.org>2023-04-06 16:04:08 +0200
committerAndreas Schneider <asn@cryptomilk.org>2023-04-11 09:06:36 +0000
commit25e1987e155e189e6c7e2984914820bcaad4e47c (patch)
treed53be978506e8d9de1e8bb0d3704440bcd953fc0 /lib/param
parent4b12dc1fb5abb94eafdb99c8a3f2451849f6657b (diff)
downloadsamba-25e1987e155e189e6c7e2984914820bcaad4e47c.tar.gz
lib:param: Fix code spelling
Best reviewed with: `git show --word-diff`. Signed-off-by: Andreas Schneider <asn@samba.org> Reviewed-by: Joseph Sutton <josephsutton@catalyst.net.nz>
Diffstat (limited to 'lib/param')
-rw-r--r--lib/param/README4
-rw-r--r--lib/param/loadparm.c6
-rw-r--r--lib/param/loadparm.h2
3 files changed, 6 insertions, 6 deletions
diff --git a/lib/param/README b/lib/param/README
index d83fe9a7a3a..11422f5c4c2 100644
--- a/lib/param/README
+++ b/lib/param/README
@@ -63,14 +63,14 @@ There is a lot of generated code, here, what generates what?
The regular format of the CPP macros in param_functions.c is used to
generate up the prototypes (mkproto.pl, mks3param_proto.pl), the service
and globals table (mkparamdefs.pl), the glue table (mmks3param.pl) and
-the initilisation of the glue table (mks3param_ctx_table.pl).
+the initialisation of the glue table (mks3param_ctx_table.pl).
I have tried combining some of these, but it just makes the scripts more
complex.
The CPP macros are defined in and expand in lib/param/loadparm.c and
source3/param/loadparm.c to read the values from the generated
-stuctures. They are CPP #included into these files so that the same
+structures. They are CPP #included into these files so that the same
macro has two definitions, depending on the system it is loading into.
diff --git a/lib/param/loadparm.h b/lib/param/loadparm.h
index af6b530366a..06e40f25c84 100644
--- a/lib/param/loadparm.h
+++ b/lib/param/loadparm.h
@@ -169,7 +169,7 @@ struct file_lists {
/*
* This should be under the HAVE_KRB5 flag but since they're used
- * in lp_kerberos_method(), they ned to be always available
+ * in lp_kerberos_method(), they need to be always available
* If you add any entries to KERBEROS_VERIFY defines, please modify USE.*KEYTAB macros
* so they remain accurate.
*/
diff --git a/lib/param/loadparm.c b/lib/param/loadparm.c
index 16cb0d47f31..15322b391f0 100644
--- a/lib/param/loadparm.c
+++ b/lib/param/loadparm.c
@@ -173,7 +173,7 @@ static const char *lpcfg_string(const char *s)
* for code compatibility between existing Samba4 and Samba3 code.
*/
/* this global context supports the lp_*() function varients */
static struct loadparm_context *global_loadparm_context;
#define FN_GLOBAL_SUBSTITUTED_STRING(fn_name,var_name) \
@@ -2111,7 +2111,7 @@ bool lpcfg_set_option(struct loadparm_context *lp_ctx, const char *option)
void lpcfg_print_parameter(struct parm_struct *p, void *ptr, FILE * f)
{
- /* For the seperation of lists values that we print below */
+ /* For the separation of lists values that we print below */
const char *list_sep = ", ";
int i;
switch (p->type)
@@ -3361,7 +3361,7 @@ static bool lpcfg_load_internal(struct loadparm_context *lp_ctx,
setenv("SMB_CONF_PATH", filename, 1);
/* set the context used by the lp_*() function
- varients */
+ variants */
global_loadparm_context = lp_ctx;
lp_ctx->loaded = true;
}
@@ -173,7 +173,7 @@ static const char *lpcfg_string(const char *s)
* for code compatibility between existing Samba4 and Samba3 code.
*/
-/* this global context supports the lp_*() function varients */
+/* this global context supports the lp_*() function variants */
static struct loadparm_context *global_loadparm_context;
#define FN_GLOBAL_SUBSTITUTED_STRING(fn_name,var_name) \